@@ -22,7 +22,12 @@ class ConferenceModel : public QAbstractListModel
     Q_PROPERTY(bool busyDownlading READ busyDownlading NOTIFY busyDownladingChanged)
 
 public:
-    enum Roles { ConferenceId = Qt::UserRole + 1, ConferenceName, ConferenceDescription, PastUpcoming };
+    enum Roles {
+        ConferenceId = Qt::UserRole + 1,
+        ConferenceName,
+        ConferenceDescription,
+        PastUpcoming
+    };
 
     explicit ConferenceModel(QObject *parent = nullptr);
 
@@ -46,8 +51,8 @@ private:
     void loadConferences();
     QString pastOrUpcoming(const int index) const;
 
-    ConferenceController *m_controller;
+    ConferenceController *m_controller = nullptr;
     QList<Conference> m_conferences;
-    bool m_busy_downloading;
+    bool m_busy_downloading = false;
 };
 #endif
